@@ -6,7 +6,8 @@ import requests
 from urllib import parse
 from dataclasses import dataclass
 
-OSS_BASE_PATH = 'arcsite-x-libs-repo'
+# OSS_BASE_PATH = 'arcsite-x-libs-repo'
+OSS_BASE_PATH = 'arcsite-x-libs-repo-2.0'
 
 @dataclass
 class BucketInfo:
@@ -39,7 +40,6 @@ def get_bucket() -> oss2.Bucket:
     
     return BUCKET_OBJECT
 
-
 def zip_dir(files_dir, dest_file):
     with zipfile.ZipFile(dest_file, 'w', zipfile.ZIP_DEFLATED, True) as ziph:
         _, zip_name = os.path.split(dest_file)
@@ -71,6 +71,10 @@ def bulk_remove_files(file_keys):
     get_bucket().batch_delete_objects(file_keys)
 
 
+def file_exist(file_key)->bool:
+    return get_bucket().object_exists(file_key)
+
+
 # def download_file(file_key, to_path):
     # get_bucket().get_object_to_file(file_key, to_path)
 
@@ -107,18 +111,6 @@ def is_legal_local_lib_dir(local_path: str, platform: str):
     return os.path.exists(p) and os.path.isdir(p)
 
 
-def get_lib_zip_file_name(name: str, version: str, platform: str):
-    return platform + '.zip'
-
-
-def get_lib_zip_file_key(name: str, version: str, platform: str):
-    zip_file_name = get_lib_zip_file_name(name, version, platform)
-    file_key = os.path.join(OSS_BASE_PATH, name, version, zip_file_name)
-    file_key = file_key.replace('\\', '/')
-
-    return file_key
-
-
 def get_platform_name() -> str:
     p = sys.platform
     if p.startswith('linux'):
@@ -135,16 +127,18 @@ def available_platforms():
 
 def available_arches(platform: str):
     data = {
-        "windows": ['x86', 'x64'],
-        'macos': ['x86_64', 'arm64', 'x64'],
+        "windows": ['x64'],
+        'macos': ['arm64', 'x64'],
         'linux': [],
         'ios': [],
-        'android': [],
+        'android': ['arm64-v8a'],
         'ios_simulator': []
     }
 
     return data.get(platform, None)
 
+def default_arch_for_platform(platform: str):
+    pass
 
 def all_available_arches():
     all_arches = []
